==> mgb-0.6.3.tar.bz2: language/lang_english_utf8/lang_main.php <==
<?php
	
	/*
	MGB 0.6 - OpenSource PHP and MySql Guestbook
	Copyright (C) 2004 - 2007 Juergen Grueneisl - http://www.m-gb.org/

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
	*/

	// =========================== //
	// lang_main.php - English 1.0 //
	// =========================== //
	//
	// This languagefile was translated by Christian Rech alias HeyJ (mail@heyj.de) 
	//
	// ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ //

	// ENGLISH strings of index.php
	$lang['install_directory_exists'] = "The install directory already exists.<br />For your own safety you should delete it!<br>But don't forget to launch <a href=\"install/upgrade.php\" title=\"Upgrade\">upgrade.php</a> after an update!";
	$lang['new_entry'] = "post an entry";
	$lang['new_entry_descr'] = "Here can you make a new guestbook entry";
	$lang['contact'] = "contact";
	$lang['contact_descr'] = "Here can you contact the administrator";
	$lang['adminpanel'] = "administration";
	$lang['adminpanel_descr'] = "Go to Login";
	$lang['entry'] = "entry";
	$lang['entries'] = "entries";
	$lang['no_entries'] = "There are currently no<br>entrys posted.";
	$lang['entries_on_pages'] = "Entrys on {PAGES} pages";
	$lang['page_forwards'] = "Browse a page forward";
	$lang['page_backwards']	= "Browse a page backwards";
	$lang['anchor']	= "Go directly to this entry";
	$lang['from'] = "from";
	$lang['at'] = "at";
	$lang['oclock']	= "am/pm(?!)";
	$lang['comment'] = "comment";
	$lang['email_yes'] = "eMail from {ENTRY_NAME}";
	$lang['email_no'] = "{ENTRY_NAME} won't get mails from the guestbook.";
	$lang['hp_of'] = "Homepage from {ENTRY_NAME}";
	$lang['gravatar'] = "Gravatar from {ENTRY_NAME}";

	// ENGLISH strings of newentry.php
	$lang['name'] = "Your Name:";
	$lang['city'] = "City:";
	$lang['email'] = "eMail:";
	$lang['icq'] = "ICQ:";
	$lang['aim'] = "AIM:";
	$lang['msn'] = "MSN:";
	$lang['homepage'] = "Homepage:";
	$lang['message'] = "Your message:";
	$lang['necessary_fields'] = "[ Mandatory fields are marked with an asterisk (*) ]";
	$lang['user_notification'] = "Notify per eMail if the entry was activated or a comment was posted.";
	$lang['user_show_email'] = "Show my eMail adress in the guestbook to allow other users to send you an eMail. If spam protection is activated nobody will see the eMail-adress directly but can send you a mail over an eMail-form.";
	$lang['send'] = "Submit";
	$lang['errormessage1'] = "Please enter a message!";
	$lang['errormessage2'] = "Please provide a valid eMailadress!";
	$lang['errormessage3'] = "Please enter your Name!";
	$lang['errormessage4'] = "is not a valid<br>eMail adress!";
	$lang['errormessage5'] = "is not a valid<br>ICQ number!";
	$lang['errormessage6'] = "The IP lock forbid an additional entry!";
	$lang['errormessage7'] = "The captcha was not entered or had mistakes!";
	$lang['errormessage8'] = "This user won't recive eMails!";
	$lang['errormessage9'] = "There was an error while sending the eMail!";
	$lang['security_code'] = "security code (captcha)";	
	$lang['captcha_what_is_that'] = "What is this?";
	$lang['captcha_wikipedia'] = "http://en.wikipedia.org/wiki/Captcha";
	$lang['captcha_tooltip'] = "A new guestbook entry or an eMail requires to transcribe the captcha to avoid automated posts. Please type all letters UPPERSIZE. If the code is unreadable, leave the text field empty and click on ''Submit''. The a new captcha will be generate. Your pervious entries will be kept. If there is no new code generated please make a right click and then ''reload'' or press [CTRL]+[R].";
	$lang['back_to_mainpage'] = "Back to the mainpage";
	$lang['back'] = "Backwards";
	$lang['entry_success_mod'] = "Your entry was successfully saved.<br>It will be reviewd by the admin and then activated.";
	$lang['entry_success'] = "Your entry was successfully saved. You can watch it right now.";
	$lang['forwarding'] = "You will be automatically forwarded in 5 seconds. If not, please click on ''Back to the mainpage''.";
	$lang['bbcodes'] = "BBCodes:";
	$lang['bbcode_help_bold'] = "bold";
	$lang['bbcode_help_italic'] = "italic";
	$lang['bbcode_help_url'] = "anchor";
	$lang['bbcode_textsize'] = "text size";
	$lang['bbcode_extrasmall'] = "tiny";
	$lang['bbcode_small'] = "small";
	$lang['bbcode_default'] = "standard";
	$lang['bbcode_big'] = "big";
	$lang['bbcode_extrabig'] = "extra big";
	$lang['bbcode_textcolor'] = "text color";
	$lang['bbcode_help_size'] = "text size";
	$lang['smileys'] = "smileys:";
	$lang['sendmail_admin_title'] = "New guestbook entry from '{NAME}'";
	$lang['sendmail_user_title'] = "Your guestbook entry at {DOMAIN}";		

	// ENGLISH strings of email.php
	$lang['email_name'] = "Your name:";
	$lang['email_email'] = "Your eMail:";
	$lang['email_message'] = "Your message:";
	$lang['email_sent_to'] = "This eMail will be send to:";
	$lang['email_send'] = "Send";
	$lang['email_caption'] = "eMail from '{NAME}' over the guestbook of {DOMAIN}";
	$lang['email_sender'] = "Sender:";
	$lang['email_receiver'] = "reviever:";
	$lang['email_from'] = "from:";
	$lang['email_sendcopytome'] = "I would like to revice a copy of this eMail.";
	$lang['email_success'] = "Your mail was successfully sent to the user.";
?>

==> mgb-0.6.4.tar.bz2: language/lang_english_utf8/lang_main.php <==
<?php
	
	/*
	MGB 0.6 - OpenSource PHP and MySql Guestbook
	Copyright (C) 2004 - 2007 Juergen Grueneisl - http://www.m-gb.org/

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
	*/

	// =========================== //
	// lang_main.php - English 1.0 //
	// =========================== //
	//
	// This languagefile was translated by Christian Rech alias HeyJ (mail@heyj.de) 
	//
	// ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ //

	// ENGLISH strings of index.php
	$lang['install_directory_exists'] = "The install directory already exists.<br />For your own safety you should delete it!<br>But don't forget to launch <a href=\"install/upgrade.php\" title=\"Upgrade\">upgrade.php</a> after an update!";
	$lang['new_entry'] = "post an entry";
	$lang['new_entry_descr'] = "Here can you make a new guestbook entry";
	$lang['contact'] = "contact";
	$lang['contact_descr'] = "Here can you contact the administrator";
	$lang['adminpanel'] = "administration";
	$lang['adminpanel_descr'] = "Go to Login";
	$lang['entry'] = "entry";
	$lang['entries'] = "entries";
	$lang['no_entries'] = "There are currently no<br>entrys posted.";
	$lang['entries_on_pages'] = "Entrys on {PAGES} pages";
	$lang['page_forwards'] = "Browse a page forward";
	$lang['page_backwards']	= "Browse a page backwards";
	$lang['anchor']	= "Go directly to this entry";
	$lang['from'] = "from";
	$lang['at'] = "at";
	$lang['oclock']	= "am/pm(?!)";
	$lang['comment'] = "comment";
	$lang['email_yes'] = "eMail from {ENTRY_NAME}";
	$lang['email_no'] = "{ENTRY_NAME} won't get mails from the guestbook.";
	$lang['hp_of'] = "Homepage from {ENTRY_NAME}";
	$lang['gravatar'] = "Gravatar from {ENTRY_NAME}";

	// ENGLISH strings of newentry.php
	$lang['name'] = "Your Name:";
	$lang['city'] = "City:";
	$lang['email'] = "eMail:";
	$lang['icq'] = "ICQ:";
	$lang['aim'] = "AIM:";
	$lang['msn'] = "MSN:";
	$lang['homepage'] = "Homepage:";
	$lang['message'] = "Your message:";
	$lang['necessary_fields'] = "[ Mandatory fields are marked with an asterisk (*) ]";
	$lang['user_notification'] = "Notify per eMail if the entry was activated or a comment was posted.";
	$lang['user_show_email'] = "Show my eMail adress in the guestbook to allow other users to send you an eMail. If spam protection is activated nobody will see the eMail-adress directly but can send you a mail over an eMail-form.";
	$lang['send'] = "Submit";
	$lang['preview'] = "Preview";
	$lang['errormessage1'] = "Please enter a message!";
	$lang['errormessage2'] = "Please provide a valid eMailadress!";
	$lang['errormessage3'] = "Please enter your Name!";
	$lang['errormessage4'] = "is not a valid<br>eMail adress!";
	$lang['errormessage5'] = "is not a valid<br>ICQ number!";
	$lang['errormessage6'] = "The IP lock forbid an additional entry!";
	$lang['errormessage7'] = "The captcha was not entered or had mistakes!";
	$lang['errormessage8'] = "This user won't recive eMails!";
	$lang['errormessage9'] = "There was an error while sending the eMail!";
	$lang['security_code'] = "security code (captcha)";	
	$lang['captcha_what_is_that'] = "What is this?";
	$lang['captcha_wikipedia'] = "http://en.wikipedia.org/wiki/Captcha";
	$lang['captcha_tooltip'] = "A new guestbook entry or an eMail requires to transcribe the captcha to avoid automated posts. Please type all letters UPPERSIZE. If the code is unreadable, leave the text field empty and click on ''Submit''. The a new captcha will be generate. Your pervious entries will be kept. If there is no new code generated please make a right click and then ''reload'' or press [CTRL]+[R].";
	$lang['back_to_mainpage'] = "Back to the mainpage";
	$lang['back'] = "Backwards";
	$lang['entry_success_mod'] = "Your entry was successfully saved.<br>It will be reviewd by the admin and then activated.";
	$lang['entry_success'] = "Your entry was successfully saved. You can watch it right now.";
	$lang['forwarding'] = "You will be automatically forwarded in 5 seconds. If not, please click on ''Back to the mainpage''.";
	$lang['bbcodes'] = "BBCodes:";
	$lang['bbcode_help_bold'] = "bold";
	$lang['bbcode_help_italic'] = "italic";
	$lang['bbcode_help_url'] = "anchor";
	$lang['bbcode_textsize'] = "text size";
	$lang['bbcode_extrasmall'] = "tiny";
	$lang['bbcode_small'] = "small";
	$lang['bbcode_default'] = "standard";
	$lang['bbcode_big'] = "big";
	$lang['bbcode_extrabig'] = "extra big";
	$lang['bbcode_textcolor'] = "text color";
	$lang['bbcode_help_size'] = "text size";
	$lang['smileys'] = "smileys:";
	$lang['sendmail_admin_title'] = "New guestbook entry from '{NAME}'";
	$lang['sendmail_user_title'] = "Your guestbook entry at {DOMAIN}";		

	// ENGLISH strings of email.php
	$lang['email_name'] = "Your name:";
	$lang['email_email'] = "Your eMail:";
	$lang['email_message'] = "Your message:";
	$lang['email_sent_to'] = "This eMail will be send to:";
	$lang['email_send'] = "Send";
	$lang['email_caption'] = "eMail from '{NAME}' over the guestbook of {DOMAIN}";
	$lang['email_sender'] = "Sender:";
	$lang['email_receiver'] = "reviever:";
	$lang['email_from'] = "from:";
	$lang['email_sendcopytome'] = "I would like to revice a copy of this eMail.";
	$lang['email_success'] = "Your mail was successfully sent to the user.";
	$lang['email_fail'] = "Your eMail couldn't be sent. Maybe there is a problem with the mail server.";
?>
